@@ -23,21 +23,19 @@ import requests
 from furl import furl
 from munch import Munch, munchify
 from packaging.version import Version
-from requests import HTTPError, Response  # noqa: F401
+from requests import HTTPError, Response
 from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
 
 from datapane import _TEST_ENV, __version__
 from datapane.client import config as c
-from datapane.client.utils import (
-    IncompatibleVersionError,
-    ReportTooLargeError,
-    UnsupportedResourceError,
-    failure_msg,
-)
+from datapane.client.utils import IncompatibleVersionError, ReportTooLargeError, UnsupportedResourceError, failure_msg
 from datapane.common import JSON, MIME, SIZE_1_MB, NPath, guess_type
 from datapane.common.utils import compress_file, log
 
-__all__ = []
+__all__ = [
+    "HTTPError",
+    "Response",
+]
 
 ################################################################################
 # Tmpfile handling
@@ -72,7 +70,7 @@ class DPTmpFile:
     def __enter__(self) -> "DPTmpFile":
         return self
 
-    def __exit__(self, exc_type, exc_value, exc_traceback):
+    def __exit__(self, exc_type, exc_value, exc_traceback):  # noqa: ANN001
         log.debug(f"Removing {self.name}")
         if self.file.exists():
             self.file.unlink()  # (missing_ok=True)
@@ -153,7 +151,7 @@ class Resource:
     # keep session as classvar to share across all DP accesses - however will be
     # tied to current instance config
     session = requests.Session()
-    timeout = None if _TEST_ENV else (6.10, 54)
+    timeout = None if _TEST_ENV else (6.10, 54)  # type: ignore
 
     def __init__(self, endpoint: str):
         # drop /api if exists
@@ -167,27 +165,29 @@ class Resource:
 
     def _check_endpoint(self, url: str):
         # raise exception if unavailable object is being accessed on the basic instance
-        basic_endpoints = ["files", "oembed", "reports", "settings", "users", "api-signup-tokens"]
-        url = furl(url)
-        url_parts = url.path.segments
+        basic_endpoints = ["files", "oembed", "reports", "settings", "users", "api-login-tokens"]
+        parsed_url: furl = furl(url)
+        url_parts = parsed_url.path.segments
         if (
-            url.host in ["datapane.com"]  # , "localhost"] - we want to access OrgSolo locally
+            parsed_url.host in ["datapane.com"]  # , "localhost"] - we want to access OrgSolo locally
             and url_parts[0] == "api"
             and url_parts[1] not in basic_endpoints
         ):
-            raise UnsupportedResourceError(f"{url_parts[1].title()} are part of Datapane Teams.")
+            raise UnsupportedResourceError(f"{url_parts[1].title()} are part of Datapane Enterprise.")
 
-    def post(self, params: t.Dict = None, **data: JSON) -> JSON:
+    def post(self, params: t.Dict = None, overwrite: bool = False, **data: JSON) -> JSON:
+        # do we ever want to support queryparams via POST?
         params = params or dict()
-        r = self.session.post(self.url, json=data, params=params, timeout=self.timeout)
+        extra_headers = {"Datapane-Object-Overwrite": "True"} if overwrite else {}
+        r = self.session.post(self.url, headers=extra_headers, json=data, params=params, timeout=self.timeout)
         return _process_res(r)
 
-    def post_files(self, files: FileList, **data: JSON) -> JSON:
+    def post_files(self, files: FileList, overwrite: bool = False, **data: JSON) -> Munch:
         # upload files using custom json-data protocol
         # build the fields
         file_header = {"Content-Encoding": "gzip"}
 
-        def mk_file_fields(field_name: str, f: Path):
+        def _mk_file_fields(field_name: str, f: Path):
             # compress the file, in-place
             # TODO - disable compression where unneeded, e.g. .gz, .zip, .png, etc
             with compress_file(f) as f_gz:
@@ -196,11 +196,13 @@ class Resource:
                     (f.name, open(f_gz, "rb"), guess_type(f), file_header),
                 )
 
-        fields = [mk_file_fields(k, x) for (k, v) in files.items() for x in v]
+        fields = [_mk_file_fields(k, x) for (k, v) in files.items() for x in v]
         fields.append(("json_data", json.dumps(data)))
 
         e = MultipartEncoder(fields=fields)
         extra_headers = {"Content-Type": f"{e.content_type}; dp-files=True"}
+        if overwrite:
+            extra_headers["Datapane-Object-Overwrite"] = "True"
 
         max_size = 25 if c.config.is_public else 100
         log.debug(f"Report size ~{e.len/SIZE_1_MB:.1f} MB")
@@ -236,7 +238,7 @@ class Resource:
             r = self.session.post(self.url, data=e, headers=extra_headers, timeout=self.timeout)
         return _process_res(r)
 
-    def get(self, empty_ok: bool = False, **params) -> JSON:
+    def get(self, empty_ok: bool = False, **params) -> Munch:
         r = self.session.get(self.url, params=params, timeout=self.timeout)
         return _process_res(r, empty_ok=empty_ok)
 
@@ -250,7 +252,7 @@ class Resource:
         _process_res(r, empty_ok=True)
 
     @contextmanager
-    def nest_endpoint(self, endpoint: str) -> t.ContextManager["Resource"]:
+    def nest_endpoint(self, endpoint: str) -> t.Generator["Resource", None, None]:
         """Returns a context manager allowing recursive nesting in endpoints"""
         a = copy(self)
         a.url = up.urljoin(a.url, endpoint)
@@ -262,7 +264,9 @@ class Resource:
 def do_download_file(download_url: t.Union[str, furl], fn: t.Optional[NPath] = None) -> NPath:
     """Download a file to `cwd`, using `fn` if provided, else Content-Disposition, else tmpfile"""
     if isinstance(download_url, str):
-        download_url: furl = furl(download_url)
+        download_url: furl = furl(download_url)  # type: ignore [no-redef]
+
+    download_url = t.cast(furl, download_url)
 
     if download_url.host is None:
         # assume the url is relative to the dp server
@@ -279,8 +283,8 @@ def do_download_file(download_url: t.Union[str, furl], fn: t.Optional[NPath] = N
             else:
                 f, fn = mkstemp()
                 os.close(f)
-        with open(fn, "wb") as f:
+        with open(fn, "wb") as ffile:
             # shutil.copyfileobj(r.raw, f)
             for chunk in r.iter_content(chunk_size=1024 * 1024):  # 1MB chunks
-                f.write(chunk)
+                ffile.write(chunk)
     return fn
